@@ -1,27 +1,27 @@
-#!perl
+package DBD::Oracle::Object;
+$DBD::Oracle::Object::VERSION = '1.75_2';
+our $AUTHORITY = 'cpan:PYTHIAN';
 # ABSTRACT: Wrapper for Oracle objects
+
 use strict;
 use warnings;
 
-package DBD::Oracle::Object;
-our $VERSION = '1.74_99'; # TRIAL VERSION
+sub type_name {  shift->{type_name}  }
 
-sub type_name { shift->{type_name} }
-
-sub attributes { @{shift->{attributes}} }
+sub attributes {  @{shift->{attributes}}  }
 
 sub attr_hash {
-    my $self = shift;
-    return $self->{attr_hash} ||= { $self->attributes };
+	my $self = shift;
+	return $self->{attr_hash} ||= { $self->attributes };
 }
 
 sub attr {
-    my $self = shift;
-    if (@_) {
-        my $key = shift;
-        return $self->attr_hash->{$key};
-    }
-    return $self->attr_hash;
+	my $self = shift;
+	if (@_) {
+		my $key = shift;
+		return $self->attr_hash->{$key};
+	}
+	return $self->attr_hash;
 }
 
 1;
@@ -38,7 +38,7 @@ DBD::Oracle::Object - Wrapper for Oracle objects
 
 =head1 VERSION
 
-version 1.74_99
+version 1.75_2
 
 =head1 AUTHORS
 
@@ -64,7 +64,7 @@ Martin J. Evans <mjevans@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2014, 2013, 2012, 2011, 2010 by Tim Bunce.
+This software is copyright (c) 1994 by Tim Bunce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
